# -*- coding: utf-8 -*-
"""
Created on Fri Dec  8 00:55:45 2017

@author: M K Shrimali
"""

import numpy as np
import matplotlib.pyplot as plt
import numpy.polynomial.legendre as lge
from scipy.optimize import fsolve,root

Ns=100
fB=2.
fA=1.
Mu=1.
Kappa=20.

class QuadratureInfo:
    def __init__(self, npoints):
        self.npoints=npoints
        A=self.A=1.e-3
        B=self.B=2.e-3
        ref_nodes,ref_weights=lge.leggauss(npoints)
        self.curve_nodes=0.5*((B-A)*ref_nodes+(B+A))
        self.curve_weights=(B-A)*ref_weights

Qs=QuadratureInfo(Ns)
xi,omga,A,B=Qs.curve_nodes,Qs.curve_weights,Qs.A,Qs.B

def Fp(f):
    fp=np.ones(xi.size)
    fp[1:xi.size-1]=np.array([(f[i]-f[i-1])/(xi[i]-xi[i-1]) for i in range(1,xi.size-1)],float)
    fp[0]=(f[1]-fA)/(xi[1]-xi[0])
    fp[-1]=(fB-f[-2])/(xi[-1]-xi[-2])
    return fp

def c(f,a,b,mu,kap):     
    return 1+4*b*(np.log(b/a)-1.) + (2*kap*omga*(b-xi)*Fp(f)**2*f**3/(mu+kap*f**4)).sum(axis=0)

def G(f,a,b,mu,kap):
    return 1.+c(f,a,b,mu,kap)*(xi-a)-4*xi*(np.log(xi/a)-1.)

def Ffunc(f,mu,kap):
    return f**3/(mu+kap*f**4)

def iesolve(f,a,b,mu,kap):
    return f-G(f,a,b,mu,kap) + np.array([(2*kap*omga*(xi[i]-xi)*Fp(f)**2*f**3/(mu+kap*f**4)).sum(axis=0) for i in range(xi.size)],float)

sol=fsolve(iesolve,sol_collocation(100).sol(xi)[0],args=(A,B,Mu,Kappa))
plt.figure(1)
plt.plot(np.linspace(A,B,xi.size),sol,label='IntegralSolver')
plt.legend(loc=0)